package com.ruoyi.frequency.rechargeorder.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.rechargeorder.entity.RechargeOrder;
import com.ruoyi.frequency.rechargeorder.model.result.RechargeOrderCount;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 充值余额订单Mapper接口
 *
 * @author liwenlong
 * @date 2023-10-25
 */
public interface RechargeOrderMapper  extends BaseMapper<RechargeOrder>
{
    /**
     * 查询充值余额订单
     *
     * @param id 充值余额订单主键
     * @return 充值余额订单
     */
    public RechargeOrder selectRechargeOrderById(Long id);

    /**
     * 查询充值余额订单列表
     *
     * @param rechargeOrder 充值余额订单
     * @return 充值余额订单集合
     */
    public List<RechargeOrder> selectRechargeOrderList(RechargeOrder rechargeOrder);

    /**
     * 新增充值余额订单
     *
     * @param rechargeOrder 充值余额订单
     * @return 结果
     */
    public int insertRechargeOrder(RechargeOrder rechargeOrder);

    /**
     * 修改充值余额订单
     *
     * @param rechargeOrder 充值余额订单
     * @return 结果
     */
    public int updateRechargeOrder(RechargeOrder rechargeOrder);

    /**
     * 删除充值余额订单
     *
     * @param id 充值余额订单主键
     * @return 结果
     */
    public int deleteRechargeOrderById(Long id);

    /**
     * 批量删除充值余额订单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRechargeOrderByIds(Long[] ids);

    RechargeOrderCount statistics(@Param("list") List<Long> rechargeOrderIdList );
}
